@@ -1,11 +1,12 @@
-package GFX::Enhancer::SystemOnEnergy;
+package GFX::Enhancer::SystemOnEnergyFilters;
 
-### main API class, 
+### main API class
 
 sub new {
 	my ($class, $pngfilename) = @_;
 
 	my $self = { energysys => GFX::Enhancer::SystemOnEnergy->new($pngfilename),
+			energyfunctions => GFX::Enhancer::SystemOnEnergyFunctions->new(),
 			};
 
 	$class = ref($class) || $class;
@@ -20,6 +21,9 @@ sub antialias_filter {
 	my $pngwriter = GFX::Enhancer::PNGWriter->new;
 
 	{
+
+		$self->{energyfunctions}->sharpen_array($self->{energysys});	
+
 		$pngwriter->write_byte_array($pngoutputfilename);
 		
 	} unless (not $pngoutputfilename);
